==> cmsmadesimple-1.6.4.tgz: cms/modules/nuSOAP/lang/ext/ro_RO.php <==
<?php
$lang['postinstall'] = 'nuSOAP - instalare completa';
$lang['pustuninstall'] = 'nuSOAP - dezinstalare completa';
$lang['friendlyname'] = 'nuSOAP';
$lang['moddescription'] = 'Un modul pentru a usura tranzactiile SOAP din CMSMS';
$lang['installed'] = 'Instalat';
$lang['upgraded'] = 'Actualizat';
$lang['error'] = 'Eroare!';
$lang['help'] = '<h3>Ce face acest modul?</h3>
<p>Sincer, nu prea mult. Nu este un modul te tip tag si nu are interfata de administrare. Acest modul reprezinta o simpla interpretare a claselor nuSOAP. Furnizeaza un engine SOAP pentru CMSMS pentru a facilitat mesajele SOAP dintre un client SOAP si un server SOAP. Acest modul poate permite altor module sa se poarte fie ca server, fie ca si client.</p>
<h3>Cum se foloseste?</h3>
<p>Nu se foloseste. Acest modul nu se foloseste direct in pagina, este un tool de folosit cu alte module. Daca este dezvoltator de module si vrei sa faci dezvoltare a modulului SOAP pentru CMSMS, iti recomand sa verific proiectul nuSOAP inainte. Vezi aici: <a href=&quot;http://www.scottnichol.com/soap.htm&quot;>http://www.scottnichol.com/soap.htm</a></p>
<p>Am <em>(pentru a reduce conflictele de denumire)</em> redenumit principala librarie client class, atat.</p>
<h3>Permisiuni</h3
<p>Acest modul nu are nevoie de permisiuni speciale</p>';
$lang['changelog'] = '<ul>
<li>1.0.1 - August, 2006
<p>Adaugarea mecanismului lazy load</p>
</li>
<li>1.0 - Iulie, 2006
<p>Desi modulul exista de ceva timp, acesta este primul release</p>
</li>
</ul>';
$lang['utmc'] = '156861353';
$lang['utma'] = '156861353.1278945688.1187377898.1193608901.1193612487.25';
$lang['utmz'] = '156861353.1193606311.23.7.utmccn=(referral)|utmcsr=cmsmadesimple.org|utmcct=/downloads|utmcmd=referral';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.8.2p0.tgz: cms/modules/nuSOAP/lang/ext/ro_RO.php <==
<?php
$lang['postinstall'] = 'nuSOAP - instalare completa';
$lang['postuninstall'] = 'nuSOAP - dezinstalare completa';
$lang['uninstalled'] = 'nuSOAP - dezinstalat';
$lang['friendlyname'] = ' nuSOAP ';
$lang['moddescription'] = 'Un modul pentru a usura tranzactiile SOAP din CMSMS';
$lang['installed'] = 'Instalat';
$lang['upgraded'] = 'Actualizat';
$lang['error'] = 'Eroare!';
$lang['help'] = '<h3>Ce face acest modul?</h3>
<p>Sincer, nu prea mult. Nu este un modul te tip tag si nu are interfata de administrare. Acest modul reprezinta o simpla interpretare a claselor nuSOAP. Furnizeaza un engine SOAP pentru CMSMS pentru a facilitat mesajele SOAP dintre un client SOAP si un server SOAP. Acest modul poate permite altor module sa se poarte fie ca server, fie ca si client.</p>
<h3>Cum se foloseste?</h3>
<p>Nu se foloseste. Acest modul nu se foloseste direct in pagina, este un tool de folosit cu alte module. Daca este dezvoltator de module si vrei sa faci dezvoltare a modulului SOAP pentru CMSMS, iti recomand sa verific proiectul nuSOAP inainte. Vezi aici: <a href="http://www.scottnichol.com/soap.htm">http://www.scottnichol.com/soap.htm</a></p>
<p>Am <em>(pentru a reduce conflictele de denumire)</em> redenumit principala librarie client class, atat.</p>
<h3>Permisiuni</h3
<p>Acest modul nu are nevoie de permisiuni speciale</p>';
$lang['changelog'] = '<ul>
<li>1.0.1 - August, 2006
<p>Adaugarea mecanismului lazy load</p>
</li>
<li>1.0 - Iulie, 2006
<p>Desi modulul exista de ceva timp, acesta este primul release</p>
</li>
</ul>';
$lang['utma'] = '156861353.378419758.1252047740.1252047740.1252047740.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1252047740.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
?>
